__all__ = ['Genome', 'Chromosome', 'Gene', 'Transcript', 'Exon', 'Protein', 'SNP']

from configuration import pyGeno_init
pyGeno_init()
